==> lxqt-powermanagement_0.17.1.orig.tar.xz: lxqt-powermanagement-0.17.1/config/translations/lxqt-config-powermanagement_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>إعدادات مراقب البطارية</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ف&amp;عّل مراقب البطارية</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>التحذير:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> ثا</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>المستوى منخفض عند:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> ٪</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>استخدم الأيقونات من السمة:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>معاينة</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>الشحن</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>تفريغ الشحن</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>عندما تكون البطارية منخفضة:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>اعرض الأيقونة:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>مضمّنة</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>المستوى: %1٪</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>ف&amp;عّل مراقب الخمول</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>وقت الخمول:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>ف&amp;عّل مراقب الغطاء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>:الإجراء عند إطباق الغطاء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>:على البطارية</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>علّق</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>أسبِت</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>أطفِئ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>:على محوّل الطاقة</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>عند استخدام شاشة &amp;خارجية</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>إعدادات إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>البطارية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>الغطاء</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>الخمول</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>اقفل الشاشة</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>علّق</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>أسبِت</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>أطفِئ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>أطفِئ الشاشة/الشاشات</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_1.1.0.orig.tar.xz: lxqt-powermanagement-1.1.0/config/translations/lxqt-config-powermanagement_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>إعدادات مراقب البطارية</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ف&amp;عّل مراقب البطارية</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>التحذير:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> ثا</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>المستوى منخفض عند:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> ٪</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>معاينة</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>الشحن</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>تفريغ الشحن</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>عندما تكون البطارية منخفضة:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>اعرض الأيقونة:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage, opaque</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>مضمّنة</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>المستوى: %1٪</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>ف&amp;عّل مراقب الخمول</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>وقت الخمول:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>ف&amp;عّل مراقب الغطاء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>:الإجراء عند إطباق الغطاء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>:على البطارية</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>علّق</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>أسبِت</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>أطفِئ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>:على محوّل الطاقة</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>عند استخدام شاشة &amp;خارجية</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>إعدادات إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>البطارية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>الغطاء</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>الخمول</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>اقفل الشاشة</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>علّق</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>أسبِت</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>أطفِئ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>أطفِئ الشاشة/الشاشات</translation>
    </message>
</context>
</TS>
